Struct fluvio_dataplane_protocol::api::RequestMessage [−]
pub struct RequestMessage<R> {
pub header: RequestHeader,
pub request: R,
}Expand description
Start of API request
Fields
header: RequestHeaderrequest: RImplementations
impl<R> RequestMessage<R>
impl<R> RequestMessage<R>
pub fn get_mut_header(&mut self) -> &mut RequestHeader
impl<R> RequestMessage<R> where
R: Request,
impl<R> RequestMessage<R> where
R: Request,
pub fn new(header: RequestHeader, request: R) -> RequestMessage<R>
pub fn new(header: RequestHeader, request: R) -> RequestMessage<R>
create with header, this assume header is constructed from higher request no api key check is performed since it is already done
pub fn new_request(request: R) -> RequestMessage<R>
pub fn new_request(request: R) -> RequestMessage<R>
create from request, header is implicilty created from key in the request
pub fn get_header_request(self) -> (RequestHeader, R)
pub fn new_response(
&self,
response: <R as Request>::Response
) -> ResponseMessage<<R as Request>::Response>
pub fn response_with_header<H>(
header: H,
response: <R as Request>::Response
) -> ResponseMessage<<R as Request>::Response> where
H: Into<i32>,
pub fn decode_response<T>(
&self,
src: &mut T,
version: i16
) -> Result<ResponseMessage<<R as Request>::Response>, Error> where
T: Buf,
pub fn decode_response_from_file<H>(
&self,
file_name: H,
version: i16
) -> Result<ResponseMessage<<R as Request>::Response>, Error> where
H: AsRef<Path>,
pub fn set_client_id<T>(self, client_id: T) -> RequestMessage<R> where
T: Into<String>,
pub fn set_client_id<T>(self, client_id: T) -> RequestMessage<R> where
T: Into<String>,
helper function to set client id