Struct fluvio_dataplane_protocol::batch::BatchHeader [−][src]
pub struct BatchHeader {
pub partition_leader_epoch: i32,
pub magic: i8,
pub crc: u32,
pub attributes: i16,
pub last_offset_delta: i32,
pub first_timestamp: i64,
pub max_time_stamp: i64,
pub producer_id: i64,
pub producer_epoch: i16,
pub first_sequence: i32,
}Fields
partition_leader_epoch: i32magic: i8crc: u32attributes: i16last_offset_delta: i32Indicates the count from the beginning of the batch to the end
Adding this to the base_offset will give the offset of the last record in this batch
first_timestamp: i64max_time_stamp: i64producer_id: i64producer_epoch: i16first_sequence: i32