Struct fluvio_dataplane_protocol::fetch::FetchPartition [−][src]
pub struct FetchPartition {
pub partition_index: i32,
pub current_leader_epoch: i32,
pub fetch_offset: i64,
pub log_start_offset: i64,
pub max_bytes: i32,
}Fields
partition_index: i32The partition index.
current_leader_epoch: i32The current leader epoch of the partition.
fetch_offset: i64The message offset.
log_start_offset: i64The earliest available offset of the follower replica. The field is only used when the request is sent by the follower.
max_bytes: i32The maximum bytes to fetch from this partition. See KIP-74 for cases where this limit may not be honored.