Struct fluvio_dataplane_protocol::fetch::FetchResponse [−][src]
pub struct FetchResponse<R> where
R: Encoder + Decoder + Default + Debug, {
pub throttle_time_ms: i32,
pub error_code: ErrorCode,
pub session_id: i32,
pub topics: Vec<FetchableTopicResponse<R>>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
error_code: ErrorCodesession_id: i32topics: Vec<FetchableTopicResponse<R>>The response topics.
Implementations
pub fn find_partition(
self,
topic: &str,
partition: i32
) -> Option<FetchablePartitionResponse<R>>