Struct fluvio_dataplane_protocol::fetch::FetchablePartitionResponse [−][src]
pub struct FetchablePartitionResponse<R> where
R: Encoder + Decoder + Default + Debug, {
pub partition_index: i32,
pub error_code: ErrorCode,
pub high_watermark: i64,
pub next_filter_offset: i64,
pub log_start_offset: i64,
pub aborted: Option<Vec<AbortedTransaction>>,
pub records: R,
}Fields
partition_index: i32The partiiton index.
error_code: ErrorCodeThe error code, or 0 if there was no fetch error
high_watermark: i64The current high water mark.
next_filter_offset: i64next offset to fetch in case of filter consumer should return that back to SPU, othewise SPU will re-turn same filter records
log_start_offset: i64The current log start offset.
aborted: Option<Vec<AbortedTransaction>>The aborted transactions.
records: RThe record data.
Implementations
offset that will be use for fetching rest of offsets this will be 1 greater than last offset of previous query If all records have been read then it will be either HW or LEO