pub struct ForgottenTopic {
pub name: String,
pub forgotten_partition_indexes: Vec<i32>,
}
The partitions indexes to forget.
Formats the value using the given formatter. Read more
decode Kafka compliant protocol values from buf
Returns the “default value” for a type. Read more
encoding contents for buffer
size of this object in bytes
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.