Struct fluvio_dataplane_protocol::produce::PartitionProduceResponse [−][src]
pub struct PartitionProduceResponse {
pub partition_index: i32,
pub error_code: ErrorCode,
pub base_offset: i64,
pub log_append_time_ms: i64,
pub log_start_offset: i64,
}Fields
partition_index: i32The partition index.
error_code: ErrorCodeThe error code, or 0 if there was no error.
base_offset: i64The base offset.
log_append_time_ms: i64The timestamp returned by broker after appending the messages. If CreateTime is used for the topic, the timestamp will be -1. If LogAppendTime is used for the topic, the timestamp will be the broker local time when the messages are appended.
log_start_offset: i64The log start offset.