Struct fluvio_dataplane_protocol::produce::ProduceRequest [−][src]
pub struct ProduceRequest<R> where
R: Encoder + Decoder + Default + Debug, {
pub transactional_id: Option<String>,
pub acks: i16,
pub timeout_ms: i32,
pub topics: Vec<TopicProduceData<R>>,
pub data: PhantomData<R>,
}Fields
transactional_id: Option<String>The transactional ID, or null if the producer is not transactional.
acks: i16The number of acknowledgments the producer requires the leader to have received before considering a request complete. Allowed values: 0 for no acknowledgments, 1 for only the leader and -1 for the full ISR.
timeout_ms: i32The timeout to await a response in miliseconds.
topics: Vec<TopicProduceData<R>>Each topic to produce to.
data: PhantomData<R>Trait Implementations