Struct fluvio_dataplane_protocol::record::Record [−][src]
Fields
preamble: RecordHeaderkey: Option<B>value: Bheaders: i64Implementations
impl<B> Record<B> where
B: Default, [src]
B: Default,
pub fn get_offset_delta(&self) -> Offset[src]
pub fn add_base_offset(&mut self, relative_base_offset: Offset)[src]
add offset delta with new relative base offset
pub fn value(&self) -> &B[src]
Returns a reference to the inner value
pub fn key(&self) -> Option<&B>[src]
Returns a reference to the inner key if it exists
pub fn into_value(self) -> B[src]
Consumes this record, returning the inner value
pub fn into_key(self) -> Option<B>[src]
Consumes this record, returning the inner key if it esists
impl Record<DefaultAsyncBuffer>[src]
pub fn new<V>(value: V) -> Self where
V: Into<Vec<u8>>, [src]
V: Into<Vec<u8>>,
pub fn new_key_value<K, V>(key: K, value: V) -> Self where
K: Into<Vec<u8>>,
V: Into<Vec<u8>>, [src]
K: Into<Vec<u8>>,
V: Into<Vec<u8>>,