Struct fluvio_dataplane_protocol::produce::ProduceRequest [−][src]
Fields
transactional_id: Option<String>The transactional ID, or null if the producer is not transactional.
acks: i16The number of acknowledgments the producer requires the leader to have received before considering a request complete. Allowed values: 0 for no acknowledgments, 1 for only the leader and -1 for the full ISR.
timeout_ms: i32The timeout to await a response in miliseconds.
topics: Vec<TopicProduceData<R>>Each topic to produce to.
data: PhantomData<R>Trait Implementations
impl<R: Debug> Debug for ProduceRequest<R> where
R: Encoder + Decoder + Default + Debug, [src]
R: Encoder + Decoder + Default + Debug,
impl<R> Decoder for ProduceRequest<R> where
R: Encoder + Decoder + Default + Debug, [src]
R: Encoder + Decoder + Default + Debug,
fn decode<T>(&mut self, src: &mut T, version: Version) -> Result<(), Error> where
T: Buf, [src]
T: Buf,
pub fn decode_from<T>(src: &mut T, version: i16) -> Result<Self, Error> where
Self: Default,
T: Buf,
Self: Default,
T: Buf,
impl<R> Default for ProduceRequest<R> where
R: Encoder + Decoder + Default + Debug, [src]
R: Encoder + Decoder + Default + Debug,
impl<R> Encoder for ProduceRequest<R> where
R: Encoder + Decoder + Default + Debug, [src]
R: Encoder + Decoder + Default + Debug,
fn encode<T>(&self, dest: &mut T, version: Version) -> Result<(), Error> where
T: BufMut, [src]
T: BufMut,
fn write_size(&self, version: Version) -> usize[src]
pub fn as_bytes(&self, version: i16) -> Result<Bytes, Error>
impl<R> Request for ProduceRequest<R> where
R: Debug + Decoder + Encoder, [src]
R: Debug + Decoder + Encoder,
const API_KEY: u16[src]
const MIN_API_VERSION: i16[src]
const MAX_API_VERSION: i16[src]
const DEFAULT_API_VERSION: i16[src]
type Response = ProduceResponse